import React from 'react';
import styled from 'styled-components';
import { Header, Text } from '../../elements';
import defaultTheme from '../../theme';
/**
 * MessageHeader
 */
const MessageHeader = styled(Header)({
    paddingBottom: '0.25rem',
});
/**
 * MessageHeader
 */
const MessageContent = styled(Text)({});
const StyledDiv = styled.div({
    position: 'relative',
    minHeight: '1em',
    margin: '1em',
    padding: '1em 1.5em',
    lineHeight: '1.5em',
}, 
// Handle message colours
({ theme, info, success, negative, floating }) => {
    const color = info
        ? 'blue'
        : success
            ? 'green'
            : negative
                ? 'red'
                : 'primaryText';
    const backgroundColor = info || success || negative
        ? theme.colors[color].verylight
        : theme.greyscale.lighter;
    const borderColour = info || success || negative
        ? theme.colors[color].default
        : theme.greyscale.dark;
    const boxShadow = floating
        ? `0 0 0 1px  ${borderColour} inset, 0 2px 4px 0  ${theme.greyscale.medium}, 0 2px 10px 0  ${theme.greyscale.medium}`
        : `0 0 0 1px ${borderColour} inset`;
    return {
        color: theme.colors[color].default,
        borderRadius: theme.sizes.borderRadius,
        backgroundColor,
        boxShadow,
    };
}, 
// Handle icon
({ icon }) => icon
    ? {
        display: 'flex',
        alignItems: 'center',
        '& > .content': {
            display: 'block',
            flex: '1 1 auto',
            verticalAlign: 'middle',
        },
        '& > .icon': {
            display: 'block',
            flex: '0 0 auto',
            opacity: 0.8,
            marginRight: '0.6em',
        },
    }
    : null);
StyledDiv.defaultProps = {
    theme: defaultTheme,
};
export const Message = (props) => {
    const { header, content, icon: Icon } = props;
    const headerNode = header && React.createElement(MessageHeader, null, header);
    const contentNode = content && React.createElement(MessageContent, null, content);
    if (Icon) {
        return (React.createElement(StyledDiv, Object.assign({}, props),
            Icon && React.createElement(Icon, { className: "icon", width: 30, height: 30 }),
            React.createElement("div", { className: "content" },
                headerNode,
                contentNode)));
    }
    return (React.createElement(StyledDiv, Object.assign({}, props),
        headerNode,
        contentNode));
};
