import { xl, sm, md, lg } from './breakpoints';
export const flexbox = ({ size, theme, }) => {
    if (!size) {
        return;
    }
    const res = {};
    if (!Array.isArray(size)) {
        res.flexBasis = `${100 * size}%`;
        res[sm({ theme })] = {
            flexBasis: `100%`,
        };
        return res;
    }
    const lastSize = size[size.length - 1] || 1;
    for (let i = 0; i < 4; i++) {
        let query = '';
        switch (i) {
            case 0:
                query = sm({ theme });
                break;
            case 1:
                query = md({ theme });
                break;
            case 2:
                query = lg({ theme });
                break;
            default:
                query = xl({ theme });
                break;
        }
        res[query] = {
            flexBasis: `${100 * (size[i] || lastSize)}%`,
        };
    }
    return res;
};
const alignable = (isRow) => ({ verticalAlign, centered, floated, }) => {
    const s = {
        justifyContent: undefined,
        alignItems: undefined,
    };
    if (verticalAlign) {
        s[isRow ? 'alignItems' : 'justifyContent'] = verticalAlign;
    }
    if (floated) {
        s[!isRow ? 'alignItems' : 'justifyContent'] =
            floated === 'left' ? 'flex-start' : 'flex-end';
        s[floated === 'left' ? 'marginRight' : 'marginLeft'] = 'auto';
    }
    if (centered) {
        s[!isRow ? 'alignItems' : 'justifyContent'] = 'center';
    }
    if (isRow) {
        s.width = '100%';
    }
    return s;
};
export const alignRow = alignable(true);
export const alignColumn = alignable();
