import React from 'react';

import { BoxProps, Box } from './Box';

/**
 * Helpers for migrating from Semantic UI
 */

export type GridType<T = {}> = React.FC<
  React.DetailedHTMLProps<
    React.HTMLAttributes<HTMLDivElement>,
    HTMLDivElement
  > &
    BoxProps &
    T & {
      as?: any;
    }
>;

export type GridParent = GridType & {
  Row: GridType;
  Column: GridType<{
    width?:
      | '1'
      | '2'
      | '3'
      | '4'
      | '5'
      | '6'
      | '7'
      | '8'
      | '9'
      | '10'
      | '11'
      | '12'
      | '13'
      | '14'
      | '15'
      | '16'
      | 1
      | 2
      | 3
      | 4
      | 5
      | 6
      | 7
      | 8
      | 9
      | 10
      | 11
      | 12
      | 13
      | 14
      | 15
      | 16;
  }>;
};

export const Grid: GridParent = ({ ref, type, ...props }) => (
  <Box {...props} type="row" />
);

Grid.Row = ({ ref, type, ...props }) => <Box type="row" {...props} />;
Grid.Column = ({ ref, type, width, ...props }) => {
  if (width) {
    const size = typeof width === 'number' ? width : parseInt(width);

    if (size) {
      props.size = size / 16;
    }
  }

  return <Box type="column" {...props} />;
};
