import React from 'react';
import styled, { keyframes, css } from 'styled-components';
import { Spinner2 as Spinner } from 'styled-icons/evil';

import defaultTheme from '../../theme';
import { SizeScale } from '../../types';

/**
 * Animation
 */

const rotate = keyframes`
  from {
    transform: rotate(0deg);
  }

  to {
    transform: rotate(360deg);
  }
`;

const animation = css`
  & > svg {
    animation: ${rotate} 1s linear infinite;
  }
`;

/**
 * Loader
 */

export interface LoaderProps {
  inverted?: boolean;
  active?: boolean;
  size?: SizeScale;
}

const LoaderDiv = styled.div<LoaderProps>(
  {
    position: 'absolute',
    top: '50%',
    left: '50%',
    margin: 0,
    textAlign: 'center',
    zIndex: 1000,
    transform: 'translateX(-50%) translateY(-50%)',
  },
  ({ theme, inverted, active, size }) => {
    const color = theme.colors[inverted ? 'white' : 'primaryText'].default;

    return {
      display: active ? 'block' : 'none',
      color,
      fontSize: theme.sizes.scale[size || 'medium'],

      '& > svg': {
        display: 'block',
        margin: '0 auto 0.5rem',
        width: '4em',
        color,
      },
    };
  },
  animation,
);

LoaderDiv.defaultProps = {
  theme: defaultTheme,
};

export const Loader: React.FC<LoaderProps> = ({ children, ...rest }) => (
  <LoaderDiv {...rest}>
    <Spinner />
    {children}
  </LoaderDiv>
);
